Package: retrosheet
Type: Package
Title: Import Professional Baseball Data from 'Retrosheet'
Version: 1.1.7
Authors@R: 
  c(person(given = "Colin",
           family = "Douglas",
           role = c("aut", "cre", "cph"),
           email = "retrosheet@colindougl.as",
           comment = c(ORCID = "https://orcid.org/0000-0002-6639-006X")),
    person(given = "Richard",
           family = "Scriven",
           role = c("aut", "cph"),
           email = "rmscriven@gmail.com"))
Date: 2026-04-18
Encoding: UTF-8
Maintainer: Colin Douglas <retrosheet@colindougl.as>
Description: A collection of tools to import and structure the (currently) single-season
    event, game-log, roster, and schedule data available from <https://www.retrosheet.org>.
    In particular, the event (a.k.a. play-by-play) files can be especially difficult to parse.
    This package does the parsing on those files, returning the requested data in the most
    practical R structure to use for sabermetric or other analyses.
URL: https://github.com/colindouglas/retrosheet
Depends: R (>= 2.10)
License: GPL (>= 2)
Imports: xml2 (>= 1.2.2), stringi (>= 0.4-1), httr (>= 1.4.1), stringr
        (>= 1.4.0), rvest (>= 0.3.5)
Note: NOTICE regarding the transfer of data from Retrosheet: The
        information used here was obtained free of charge from and is
        copyrighted by Retrosheet. Interested parties may contact
        Retrosheet at "www.retrosheet.org".
RoxygenNote: 7.3.3
Suggests: testthat (>= 3.0.0), rmarkdown (>= 2.0.0)
BugReports: https://github.com/colindouglas/retrosheet/issues
NeedsCompilation: no
Packaged: 2026-04-20 11:19:53 UTC; colin
Author: Colin Douglas [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-6639-006X>),
  Richard Scriven [aut, cph]
Repository: CRAN
Date/Publication: 2026-04-20 13:00:15 UTC
Built: R 4.6.0; ; 2026-04-26 09:56:42 UTC; unix
