# Generated by roxygen2: do not edit by hand

export(gamelogFields)
export(getFileNames)
export(getParkIDs)
export(getPartialGamelog)
export(getRetrosheet)
export(getTeamIDs)
export(get_retrosheet)
importFrom(httr,RETRY)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,timeout)
importFrom(httr,write_disk)
importFrom(rvest,html_attr)
importFrom(rvest,html_nodes)
importFrom(stats,setNames)
importFrom(stringi,stri_split_fixed)
importFrom(stringr,str_extract)
importFrom(utils,read.csv)
importFrom(utils,type.convert)
importFrom(utils,unzip)
importFrom(xml2,read_html)
